@@ -6,13 +6,13 @@ plan(sequential)
 vocab <- generateVocab(nTopics = 5, nSentiments = 3, nWords = 5, nCommonWords = 2)
 toks <- generateDocuments(vocab, nDocs = 10, L1prior = 5, L2prior = 5, nWords = 10, nClass = 2)
 generated_sentopicmodel <- sentopicmodel(toks)
-generated_sentopicmodel <- grow(generated_sentopicmodel, 20, displayProgress = FALSE, nChains = 2)
+generated_sentopicmodel <- fit(generated_sentopicmodel, 20, displayProgress = FALSE, nChains = 2)
 
 
 test_that("multiple chains works", {
   expect_true(all(sapply(generated_sentopicmodel, check_integrity)))
   expect_s3_class(generated_sentopicmodel, "multiChains")
-  expect_message(generated_sentopicmodel <- grow(generated_sentopicmodel, 20, displayProgress = FALSE), NA)
+  expect_message(generated_sentopicmodel <- fit(generated_sentopicmodel, 20, displayProgress = FALSE), NA)
   expect_true(all(sapply(generated_sentopicmodel, check_integrity)))
 })
 
@@ -32,13 +32,13 @@ if (Sys.getenv("R_COVR") != "true") {
 
   plan(multisession, workers = 2)
   generated_sentopicmodel <- sentopicmodel(toks)
-  generated_sentopicmodel <- grow(generated_sentopicmodel, 20, displayProgress = TRUE, nChains = 10)
+  generated_sentopicmodel <- fit(generated_sentopicmodel, 20, displayProgress = TRUE, nChains = 10)
 
 
   test_that("parallel works", {
     expect_true(all(sapply(generated_sentopicmodel, check_integrity)))
     expect_s3_class(generated_sentopicmodel, "multiChains")
-    expect_message(generated_sentopicmodel <- grow(generated_sentopicmodel, 20, displayProgress = FALSE), NA)
+    expect_message(generated_sentopicmodel <- fit(generated_sentopicmodel, 20, displayProgress = FALSE), NA)
     expect_true(all(sapply(generated_sentopicmodel, check_integrity)))
   })
 
@@ -46,53 +46,53 @@ if (Sys.getenv("R_COVR") != "true") {
     plan(sequential)
     generated_sentopicmodel <- sentopicmodel(toks)
     set.seed(123)
-    sentopicmodel_1 <- grow(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 1)
+    sentopicmodel_1 <- fit(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 1)
     set.seed(123)
-    sentopicmodel_2 <- grow(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 1)
+    sentopicmodel_2 <- fit(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 1)
     expect_identical(sentopicmodel_1, sentopicmodel_2)
-    sentopicmodel_1 <- grow(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 1, seed = 123)
-    sentopicmodel_2 <- grow(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 1, seed = 123)
+    sentopicmodel_1 <- fit(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 1, seed = 123)
+    sentopicmodel_2 <- fit(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 1, seed = 123)
     expect_identical(sentopicmodel_1, sentopicmodel_2)
-    sentopicmodel_1 <- grow(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 1, seed = 1234)
+    sentopicmodel_1 <- fit(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 1, seed = 1234)
     expect_false(identical(sentopicmodel_1, sentopicmodel_2))
-    sentopicmodel_1 <- grow(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 1, seed = NULL)
-    sentopicmodel_2 <- grow(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 1, seed = NULL)
+    sentopicmodel_1 <- fit(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 1, seed = NULL)
+    sentopicmodel_2 <- fit(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 1, seed = NULL)
     expect_false(identical(sentopicmodel_1, sentopicmodel_2))
 
-    sentopicmodel_1 <- grow(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2, seed = 123)
-    sentopicmodel_2 <- grow(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2, seed = 123)
+    sentopicmodel_1 <- fit(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2, seed = 123)
+    sentopicmodel_2 <- fit(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2, seed = 123)
     expect_identical(sentopicmodel_1, sentopicmodel_2)
-    sentopicmodel_1 <- grow(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2, seed = 1234)
+    sentopicmodel_1 <- fit(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2, seed = 1234)
     expect_false(identical(sentopicmodel_1, sentopicmodel_2))
-    sentopicmodel_1 <- grow(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2, seed = NULL)
-    sentopicmodel_2 <- grow(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2, seed = NULL)
+    sentopicmodel_1 <- fit(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2, seed = NULL)
+    sentopicmodel_2 <- fit(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2, seed = NULL)
     expect_false(identical(sentopicmodel_1, sentopicmodel_2))
 
     plan(multisession, workers = 2)
     set.seed(123)
-    sentopicmodel_1 <- grow(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2)
+    sentopicmodel_1 <- fit(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2)
     set.seed(123)
-    sentopicmodel_2 <- grow(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2)
+    sentopicmodel_2 <- fit(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2)
     expect_identical(sentopicmodel_1, sentopicmodel_2)
-    sentopicmodel_1 <- grow(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2, seed = NULL)
-    sentopicmodel_2 <- grow(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2, seed = NULL)
+    sentopicmodel_1 <- fit(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2, seed = NULL)
+    sentopicmodel_2 <- fit(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2, seed = NULL)
     expect_false(identical(sentopicmodel_1, sentopicmodel_2))
-    sentopicmodel_1 <- grow(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2, seed = 1234)
-    sentopicmodel_2 <- grow(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2, seed = 123)
+    sentopicmodel_1 <- fit(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2, seed = 1234)
+    sentopicmodel_2 <- fit(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2, seed = 123)
     expect_false(identical(sentopicmodel_1, sentopicmodel_2))
-    sentopicmodel_1 <- grow(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2, seed = 123)
+    sentopicmodel_1 <- fit(generated_sentopicmodel, 2, displayProgress = FALSE, nChains = 2, seed = 123)
     expect_identical(sentopicmodel_1, sentopicmodel_2)
 
-    sentopicmodel_11 <- grow(sentopicmodel_1, 2, displayProgress = FALSE, nChains = 2, seed = 1234)
-    sentopicmodel_22 <- grow(sentopicmodel_2, 2, displayProgress = FALSE, nChains = 2, seed = 1234)
+    sentopicmodel_11 <- fit(sentopicmodel_1, 2, displayProgress = FALSE, nChains = 2, seed = 1234)
+    sentopicmodel_22 <- fit(sentopicmodel_2, 2, displayProgress = FALSE, nChains = 2, seed = 1234)
     expect_identical(sentopicmodel_11, sentopicmodel_22)
-    sentopicmodel_22 <- grow(sentopicmodel_2, 2, displayProgress = FALSE, nChains = 2, seed = 123)
+    sentopicmodel_22 <- fit(sentopicmodel_2, 2, displayProgress = FALSE, nChains = 2, seed = 123)
     expect_false(identical(sentopicmodel_11, sentopicmodel_22))
-    sentopicmodel_11 <- grow(sentopicmodel_1, 2, displayProgress = FALSE, nChains = 2, seed = NULL)
-    sentopicmodel_22 <- grow(sentopicmodel_2, 2, displayProgress = FALSE, nChains = 2, seed = NULL)
+    sentopicmodel_11 <- fit(sentopicmodel_1, 2, displayProgress = FALSE, nChains = 2, seed = NULL)
+    sentopicmodel_22 <- fit(sentopicmodel_2, 2, displayProgress = FALSE, nChains = 2, seed = NULL)
     expect_false(identical(sentopicmodel_11, sentopicmodel_22))
 
-    
+
     # cran is annoyed by more than 2 cores => skip it
     skip_on_cran()
     # for CMD check
@@ -107,16 +107,16 @@ if (Sys.getenv("R_COVR") != "true") {
 
     plan(multisession, workers = num_workers)
     ### this works !
-    sentopicmodel_1 <- grow(generated_sentopicmodel, 5, displayProgress = FALSE, nChains = 3, seed = 1234)
+    sentopicmodel_1 <- fit(generated_sentopicmodel, 5, displayProgress = FALSE, nChains = 3, seed = 1234)
     plan(multisession, workers = 2)
-    sentopicmodel_2 <- grow(generated_sentopicmodel, 5, displayProgress = FALSE, nChains = 3, seed = 1234)
+    sentopicmodel_2 <- fit(generated_sentopicmodel, 5, displayProgress = FALSE, nChains = 3, seed = 1234)
     plan(multisession, workers = 1)
-    sentopicmodel_3 <- grow(generated_sentopicmodel, 5, displayProgress = FALSE, nChains = 3, seed = 1234)
+    sentopicmodel_3 <- fit(generated_sentopicmodel, 5, displayProgress = FALSE, nChains = 3, seed = 1234)
     expect_identical(sentopicmodel_1, sentopicmodel_2)
     expect_identical(sentopicmodel_1, sentopicmodel_3)
-    
+
     plan(multisession, workers = 2)
-    sentopicmodel_3 <- grow(generated_sentopicmodel, 5, displayProgress = FALSE, nChains = 3, seed = 123)
+    sentopicmodel_3 <- fit(generated_sentopicmodel, 5, displayProgress = FALSE, nChains = 3, seed = 123)
     expect_false(identical(sentopicmodel_1, sentopicmodel_3))
   })
 }
@@ -124,7 +124,7 @@ if (Sys.getenv("R_COVR") != "true") {
 toks <- generateDocuments(vocab, nDocs = 10, L1prior = 5, L2prior = 5, nWords = 110, nClass = 2)
 lex <- generatePartialLexicon(toks)
 generated_sentopicmodel <- sentopicmodel(toks, lex)
-generated_sentopicmodel <- grow(generated_sentopicmodel, 20, displayProgress = FALSE, nChains = 3)
+generated_sentopicmodel <- fit(generated_sentopicmodel, 20, displayProgress = FALSE, nChains = 3)
 
 test_that("scores & distances works", {
   plan(multisession, workers = if (Sys.getenv("R_COVR") != "true") 2 else 1)
@@ -152,12 +152,12 @@ test_that("scores & distances works", {
 test_that("equality between euclidean distances", {
   toks <- ECB_press_conferences_tokens[1:10]
   LDA <- LDA(toks)
-  LDAs <- grow(LDA, 10, nChains = 5)
+  LDAs <- fit(LDA, 10, nChains = 5)
   expect_equal(
     chainsDistances(LDAs),
     chainsDistances(LDAs, method = "invariantEuclidean"))
   rJST <- rJST(toks, S = 1)
-  rJSTs <- grow(rJST, 10, nChains = 5)
+  rJSTs <- fit(rJST, 10, nChains = 5)
   expect_equal(
     chainsDistances(rJSTs),
     chainsDistances(rJSTs, method = "invariantEuclidean"))
